==> react-view-router-2.1.2.tgz: package/drawer/es/index.js <==
function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import React from 'react';
import { RouterViewComponent, renderRoute, config, isFunction } from 'react-view-router';
import Drawer from './drawer';
import '../style/drawer.css';

class RouterDrawer extends RouterViewComponent {
  constructor(props) {
    super(props);

    _defineProperty(this, "drawer", void 0);

    _defineProperty(this, "needAnimation", void 0);

    this.needAnimation = false;
    Object.assign(this.state, {
      openDrawer: false,
      prevRoute: null,
      _routerDrawer: true
    });
    this._handleClose = this._handleClose.bind(this);
    this._handleAnimationEnd = this._handleAnimationEnd.bind(this);
  }

  _refreshCurrentRoute(state, newState, callback) {
    if (!state) state = this.state;
    const prevRoute = state.currentRoute;
    if (!newState) newState = {
      openDrawer: false
    };else newState.openDrawer = false;

    const currentRoute = super._refreshCurrentRoute(state, newState, callback);

    let openDrawer;

    if (this.isNull(prevRoute) && !this.isNull(currentRoute)) {
      let r = state._routerParent && state._routerParent.state.currentRoute;
      r && Object.keys(r.componentInstances).forEach(key => {
        const c = r && r.componentInstances[key];
        if (c && c.componentWillUnactivate) c.componentWillUnactivate();
      });
      openDrawer = true;
    }

    if (!this.isNull(prevRoute) && this.isNull(currentRoute)) {
      let r = state._routerParent && state._routerParent.state.currentRoute;
      r && Object.keys(r.componentInstances).forEach(key => {
        const c = r && r.componentInstances[key];
        if (c && c.componentDidActivate) c.componentDidActivate();
      });
      openDrawer = false;
    }

    if (openDrawer !== undefined && this.state.openDrawer !== openDrawer) {
      newState.openDrawer = openDrawer;
      if (!openDrawer && this.props.position && !this.isNull(this.state.prevRoute)) newState.prevRoute = prevRoute;
    }

    if (this.state && this.state._routerInited) this.setState(newState);else Object.assign(state, newState);
    return currentRoute;
  }

  _handleAnimationEnd() {
    if (!this.props.position) return;
    if (!this.state.openDrawer) this.setState({
      prevRoute: null
    });
  }

  _handleClose() {
    const {
      router,
      parentRoute
    } = this.state;

    if (router) {
      if (parentRoute && router.currentRoute && router.currentRoute.path !== parentRoute.path) router.back();
    }

    this.setState({
      openDrawer: false
    });
  }

  getZindex() {
    const currentRoute = this.state.currentRoute;
    if (!currentRoute) return config.zIndexStart;
    const {
      zIndex
    } = this.props;

    if (zIndex !== undefined) {
      if (isFunction(zIndex)) return zIndex(currentRoute, {
        config,
        view: this
      });
      return zIndex;
    }

    return config.zIndexStart + currentRoute.depth * config.zIndexStep;
  }

  shouldComponentUpdate(nextProps, nextState) {
    if (this.state.openDrawer !== nextState.openDrawer) return true;
    if (this.state.prevRoute !== nextState.prevRoute) return true;
    return super.shouldComponentUpdate(nextProps, nextState);
  }

  renderCurrent(currentRoute) {
    const {
      routes
    } = this.state;
    if (!this.state.router || !currentRoute) return null; // eslint-disable-next-line

    const _this$props = this.props,
          {
      _updateRef,
      router,
      container: oldContainer,
      prefixCls,
      position,
      zIndexStart,
      delay,
      drawerClassName,
      children,
      touch
    } = _this$props,
          props = _objectWithoutProperties(_this$props, ["_updateRef", "router", "container", "prefixCls", "position", "zIndexStart", "delay", "drawerClassName", "children", "touch"]);

    const {
      openDrawer,
      prevRoute
    } = this.state;
    const {
      query,
      params
    } = this.state.router.currentRoute || {};
    Object.defineProperty(props, 'drawer', {
      get() {
        return this.drawer;
      },

      configurable: true
    });
    let ret = renderRoute(!openDrawer ? prevRoute : currentRoute, routes, props, children, {
      name: this.name,
      query,
      params,
      container: comp => {
        if (oldContainer) comp = oldContainer(comp, currentRoute, props);
        let needAnimation = this.state.router && !this.isNull(this.state.router.prevRoute);
        if (!openDrawer) needAnimation = this.needAnimation && needAnimation;
        this.needAnimation = Boolean(needAnimation);
        comp = React.createElement(Drawer, {
          ref: el => this.drawer = el,
          prefixCls,
          className: drawerClassName,
          touch: touch && needAnimation,
          transitionName: needAnimation && position ? `rvr-slide-${position}` : '',
          open: Boolean(openDrawer && comp),
          zIndex: this.getZindex(),
          onAnimateLeave: this._handleAnimationEnd,
          onClose: this._handleClose
        }, comp);
        return comp;
      },
      ref: this._updateRef
    });
    return ret;
  }

}

_defineProperty(RouterDrawer, "defaultProps", void 0);

RouterDrawer.defaultProps = _objectSpread({}, RouterViewComponent.defaultProps, {
  prefixCls: 'rvr-route-drawer',
  position: 'right',
  touch: true
});
export default React.forwardRef((props, ref) => React.createElement(RouterDrawer, _objectSpread({}, props, {
  _updateRef: ref
})));

==> react-view-router-2.1.7.tgz: package/drawer/es/index.js <==
function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); enumerableOnly && (symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; })), keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = null != arguments[i] ? arguments[i] : {}; i % 2 ? ownKeys(Object(source), !0).forEach(function (key) { _defineProperty(target, key, source[key]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)) : ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import React from 'react';
import { RouterViewComponent, renderRoute, config, isFunction } from 'react-view-router';
import Drawer from './drawer';
import '../style/drawer.css';

class RouterDrawer extends RouterViewComponent {
  constructor(props) {
    super(props);

    _defineProperty(this, "drawer", void 0);

    _defineProperty(this, "needAnimation", void 0);

    this.needAnimation = false;
    Object.assign(this.state, {
      openDrawer: false,
      prevRoute: null,
      _routerDrawer: true
    });
    this._handleClose = this._handleClose.bind(this);
    this._handleAnimationEnd = this._handleAnimationEnd.bind(this);
  }

  _refreshCurrentRoute(state, newState, callback) {
    if (!state) state = this.state;
    const prevRoute = state.currentRoute;
    if (!newState) newState = {
      openDrawer: false
    };else newState.openDrawer = false;

    const currentRoute = super._refreshCurrentRoute(state, newState, callback);

    let openDrawer;

    if (this.isNull(prevRoute) && !this.isNull(currentRoute)) {
      let r = state._routerParent && state._routerParent.state.currentRoute;
      r && Object.keys(r.componentInstances).forEach(key => {
        const c = r && r.componentInstances[key];
        if (c && c.componentWillUnactivate) c.componentWillUnactivate();
      });
      openDrawer = true;
    }

    if (!this.isNull(prevRoute) && this.isNull(currentRoute)) {
      let r = state._routerParent && state._routerParent.state.currentRoute;
      r && Object.keys(r.componentInstances).forEach(key => {
        const c = r && r.componentInstances[key];
        if (c && c.componentDidActivate) c.componentDidActivate();
      });
      openDrawer = false;
    }

    if (openDrawer !== undefined && this.state.openDrawer !== openDrawer) {
      newState.openDrawer = openDrawer;
      if (!openDrawer && this.props.position && !this.isNull(this.state.prevRoute)) newState.prevRoute = prevRoute;
    }

    if (this.state && this.state._routerInited) this.setState(newState);else Object.assign(state, newState);
    return currentRoute;
  }

  _handleAnimationEnd() {
    if (!this.props.position) return;
    if (!this.state.openDrawer) this.setState({
      prevRoute: null
    });
  }

  _handleClose() {
    const {
      router,
      parentRoute
    } = this.state;

    if (router) {
      if (parentRoute && router.currentRoute && router.currentRoute.path !== parentRoute.path) router.back();
    }

    this.setState({
      openDrawer: false
    });
  }

  getZindex() {
    const currentRoute = this.state.currentRoute;
    if (!currentRoute) return config.zIndexStart;
    const {
      zIndex
    } = this.props;

    if (zIndex !== undefined) {
      if (isFunction(zIndex)) return zIndex(currentRoute, {
        config,
        view: this
      });
      return zIndex;
    }

    return config.zIndexStart + currentRoute.depth * config.zIndexStep;
  }

  shouldComponentUpdate(nextProps, nextState) {
    if (this.state.openDrawer !== nextState.openDrawer) return true;
    if (this.state.prevRoute !== nextState.prevRoute) return true;
    return super.shouldComponentUpdate(nextProps, nextState);
  }

  renderCurrent(currentRoute) {
    const {
      routes
    } = this.state;
    if (!this.state.router || !currentRoute) return null;
    const {
      children,
      props
    } = this.getComponentProps();
    const {
      openDrawer,
      prevRoute
    } = this.state;
    const {
      query,
      params
    } = this.state.router.currentRoute || {};
    Object.defineProperty(props, 'drawer', {
      get() {
        return this.drawer;
      },

      configurable: true
    });
    let ret = renderRoute(!openDrawer ? prevRoute : currentRoute, routes, props, children, {
      name: this.name,
      query,
      params,
      ref: this._updateRef
    });
    return ret;
  }

  renderContainer(current, currentRoute) {
    let result = super.renderContainer(current, currentRoute);
    if (this.isNull(currentRoute)) return result;
    const {
      prefixCls,
      position,
      drawerClassName,
      touch
    } = this.props;
    const {
      openDrawer
    } = this.state;
    let needAnimation = this.state.router && !this.isNull(this.state.router.prevRoute);
    if (!openDrawer) needAnimation = this.needAnimation && needAnimation;
    this.needAnimation = Boolean(needAnimation);
    result = React.createElement(Drawer, {
      ref: el => this.drawer = el,
      prefixCls,
      className: drawerClassName,
      touch: touch && needAnimation,
      transitionName: needAnimation && position ? `rvr-slide-${position}` : '',
      open: Boolean(openDrawer && result),
      zIndex: this.getZindex(),
      onAnimateLeave: this._handleAnimationEnd,
      onClose: this._handleClose
    }, result);
    return result;
  }

}

_defineProperty(RouterDrawer, "defaultProps", void 0);

RouterDrawer.defaultProps = _objectSpread(_objectSpread({}, RouterViewComponent.defaultProps), {}, {
  prefixCls: 'rvr-route-drawer',
  position: 'right',
  touch: true,
  excludeProps: [...RouterViewComponent.defaultProps.excludeProps, 'drawerClassName', 'touch', 'prefixCls', 'position', 'zIndexStart', 'delay']
});
export default React.forwardRef((props, ref) => React.createElement(RouterDrawer, _objectSpread(_objectSpread({}, props), {}, {
  _updateRef: ref
})));
